==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_entities/routeequipment_001/RouteEquipment.java <==

package net.datastream.schemas.mp_entities.routeequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTTYPE_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMGEOREF" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOGEOREF" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSETDIRECTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeequipmentid",
    "routeequipmenttype",
    "frompoint",
    "fromrefdesc",
    "fromgeoref",
    "topoint",
    "torefdesc",
    "togeoref",
    "fromreferenceid",
    "fromoffset",
    "fromoffsetdirection",
    "toreferenceid",
    "tooffset",
    "tooffsetdirection"
})
@XmlRootElement(name = "RouteEquipment")
public class RouteEquipment {

    @XmlElement(name = "ROUTEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTID_Type routeequipmentid;
    @XmlElement(name = "ROUTEEQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTTYPE_Type routeequipmenttype;
    @XmlElement(name = "FROMPOINT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY frompoint;
    @XmlElement(name = "FROMREFDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String fromrefdesc;
    @XmlElement(name = "FROMGEOREF", namespace = "http://schemas.datastream.net/MP_fields")
    protected String fromgeoref;
    @XmlElement(name = "TOPOINT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY topoint;
    @XmlElement(name = "TOREFDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String torefdesc;
    @XmlElement(name = "TOGEOREF", namespace = "http://schemas.datastream.net/MP_fields")
    protected String togeoref;
    @XmlElement(name = "FROMREFERENCEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEID_Type fromreferenceid;
    @XmlElement(name = "FROMOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY fromoffset;
    @XmlElement(name = "FROMOFFSETDIRECTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type fromoffsetdirection;
    @XmlElement(name = "TOREFERENCEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEID_Type toreferenceid;
    @XmlElement(name = "TOOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY tooffset;
    @XmlElement(name = "TOOFFSETDIRECTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type tooffsetdirection;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété routeequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public ROUTEEQUIPMENTID_Type getROUTEEQUIPMENTID() {
        return routeequipmentid;
    }

    /**
     * Définit la valeur de la propriété routeequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public void setROUTEEQUIPMENTID(ROUTEEQUIPMENTID_Type value) {
        this.routeequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété routeequipmenttype.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public ROUTEEQUIPMENTTYPE_Type getROUTEEQUIPMENTTYPE() {
        return routeequipmenttype;
    }

    /**
     * Définit la valeur de la propriété routeequipmenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public void setROUTEEQUIPMENTTYPE(ROUTEEQUIPMENTTYPE_Type value) {
        this.routeequipmenttype = value;
    }

    /**
     * Obtient la valeur de la propriété frompoint.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMPOINT() {
        return frompoint;
    }

    /**
     * Définit la valeur de la propriété frompoint.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMPOINT(QUANTITY value) {
        this.frompoint = value;
    }

    /**
     * Obtient la valeur de la propriété fromrefdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROMREFDESC() {
        return fromrefdesc;
    }

    /**
     * Définit la valeur de la propriété fromrefdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROMREFDESC(String value) {
        this.fromrefdesc = value;
    }

    /**
     * Obtient la valeur de la propriété fromgeoref.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROMGEOREF() {
        return fromgeoref;
    }

    /**
     * Définit la valeur de la propriété fromgeoref.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROMGEOREF(String value) {
        this.fromgeoref = value;
    }

    /**
     * Obtient la valeur de la propriété topoint.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOPOINT() {
        return topoint;
    }

    /**
     * Définit la valeur de la propriété topoint.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOPOINT(QUANTITY value) {
        this.topoint = value;
    }

    /**
     * Obtient la valeur de la propriété torefdesc.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOREFDESC() {
        return torefdesc;
    }

    /**
     * Définit la valeur de la propriété torefdesc.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOREFDESC(String value) {
        this.torefdesc = value;
    }

    /**
     * Obtient la valeur de la propriété togeoref.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOGEOREF() {
        return togeoref;
    }

    /**
     * Définit la valeur de la propriété togeoref.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOGEOREF(String value) {
        this.togeoref = value;
    }

    /**
     * Obtient la valeur de la propriété fromreferenceid.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getFROMREFERENCEID() {
        return fromreferenceid;
    }

    /**
     * Définit la valeur de la propriété fromreferenceid.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setFROMREFERENCEID(LINEARREFERENCEID_Type value) {
        this.fromreferenceid = value;
    }

    /**
     * Obtient la valeur de la propriété fromoffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMOFFSET() {
        return fromoffset;
    }

    /**
     * Définit la valeur de la propriété fromoffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMOFFSET(QUANTITY value) {
        this.fromoffset = value;
    }

    /**
     * Obtient la valeur de la propriété fromoffsetdirection.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getFROMOFFSETDIRECTION() {
        return fromoffsetdirection;
    }

    /**
     * Définit la valeur de la propriété fromoffsetdirection.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setFROMOFFSETDIRECTION(UCODEID_Type value) {
        this.fromoffsetdirection = value;
    }

    /**
     * Obtient la valeur de la propriété toreferenceid.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getTOREFERENCEID() {
        return toreferenceid;
    }

    /**
     * Définit la valeur de la propriété toreferenceid.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setTOREFERENCEID(LINEARREFERENCEID_Type value) {
        this.toreferenceid = value;
    }

    /**
     * Obtient la valeur de la propriété tooffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOOFFSET() {
        return tooffset;
    }

    /**
     * Définit la valeur de la propriété tooffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOOFFSET(QUANTITY value) {
        this.tooffset = value;
    }

    /**
     * Obtient la valeur de la propriété tooffsetdirection.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getTOOFFSETDIRECTION() {
        return tooffsetdirection;
    }

    /**
     * Définit la valeur de la propriété tooffsetdirection.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setTOOFFSETDIRECTION(UCODEID_Type value) {
        this.tooffsetdirection = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_entities/routeequipment_001/RouteEquipment.java <==

package net.datastream.schemas.mp_entities.routeequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.LINEARREFERENCEID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.ROUTEEQUIPMENTTYPE_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ROUTEEQUIPMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMGEOREF" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOPOINT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFDESC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOGEOREF" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMOFFSETDIRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOREFERENCEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOOFFSETDIRECTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "routeequipmentid",
    "routeequipmenttype",
    "frompoint",
    "fromrefdesc",
    "fromgeoref",
    "topoint",
    "torefdesc",
    "togeoref",
    "fromreferenceid",
    "fromoffset",
    "fromoffsetdirection",
    "toreferenceid",
    "tooffset",
    "tooffsetdirection"
})
@XmlRootElement(name = "RouteEquipment")
public class RouteEquipment {

    @XmlElement(name = "ROUTEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTID_Type routeequipmentid;
    @XmlElement(name = "ROUTEEQUIPMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ROUTEEQUIPMENTTYPE_Type routeequipmenttype;
    @XmlElement(name = "FROMPOINT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY frompoint;
    @XmlElement(name = "FROMREFDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String fromrefdesc;
    @XmlElement(name = "FROMGEOREF", namespace = "http://schemas.datastream.net/MP_fields")
    protected String fromgeoref;
    @XmlElement(name = "TOPOINT", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY topoint;
    @XmlElement(name = "TOREFDESC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String torefdesc;
    @XmlElement(name = "TOGEOREF", namespace = "http://schemas.datastream.net/MP_fields")
    protected String togeoref;
    @XmlElement(name = "FROMREFERENCEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEID_Type fromreferenceid;
    @XmlElement(name = "FROMOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY fromoffset;
    @XmlElement(name = "FROMOFFSETDIRECTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type fromoffsetdirection;
    @XmlElement(name = "TOREFERENCEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LINEARREFERENCEID_Type toreferenceid;
    @XmlElement(name = "TOOFFSET", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY tooffset;
    @XmlElement(name = "TOOFFSETDIRECTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type tooffsetdirection;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the routeequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public ROUTEEQUIPMENTID_Type getROUTEEQUIPMENTID() {
        return routeequipmentid;
    }

    /**
     * Sets the value of the routeequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTID_Type }
     *     
     */
    public void setROUTEEQUIPMENTID(ROUTEEQUIPMENTID_Type value) {
        this.routeequipmentid = value;
    }

    /**
     * Gets the value of the routeequipmenttype property.
     * 
     * @return
     *     possible object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public ROUTEEQUIPMENTTYPE_Type getROUTEEQUIPMENTTYPE() {
        return routeequipmenttype;
    }

    /**
     * Sets the value of the routeequipmenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link ROUTEEQUIPMENTTYPE_Type }
     *     
     */
    public void setROUTEEQUIPMENTTYPE(ROUTEEQUIPMENTTYPE_Type value) {
        this.routeequipmenttype = value;
    }

    /**
     * Gets the value of the frompoint property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMPOINT() {
        return frompoint;
    }

    /**
     * Sets the value of the frompoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMPOINT(QUANTITY value) {
        this.frompoint = value;
    }

    /**
     * Gets the value of the fromrefdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROMREFDESC() {
        return fromrefdesc;
    }

    /**
     * Sets the value of the fromrefdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROMREFDESC(String value) {
        this.fromrefdesc = value;
    }

    /**
     * Gets the value of the fromgeoref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROMGEOREF() {
        return fromgeoref;
    }

    /**
     * Sets the value of the fromgeoref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROMGEOREF(String value) {
        this.fromgeoref = value;
    }

    /**
     * Gets the value of the topoint property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOPOINT() {
        return topoint;
    }

    /**
     * Sets the value of the topoint property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOPOINT(QUANTITY value) {
        this.topoint = value;
    }

    /**
     * Gets the value of the torefdesc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOREFDESC() {
        return torefdesc;
    }

    /**
     * Sets the value of the torefdesc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOREFDESC(String value) {
        this.torefdesc = value;
    }

    /**
     * Gets the value of the togeoref property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOGEOREF() {
        return togeoref;
    }

    /**
     * Sets the value of the togeoref property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOGEOREF(String value) {
        this.togeoref = value;
    }

    /**
     * Gets the value of the fromreferenceid property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getFROMREFERENCEID() {
        return fromreferenceid;
    }

    /**
     * Sets the value of the fromreferenceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setFROMREFERENCEID(LINEARREFERENCEID_Type value) {
        this.fromreferenceid = value;
    }

    /**
     * Gets the value of the fromoffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getFROMOFFSET() {
        return fromoffset;
    }

    /**
     * Sets the value of the fromoffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setFROMOFFSET(QUANTITY value) {
        this.fromoffset = value;
    }

    /**
     * Gets the value of the fromoffsetdirection property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getFROMOFFSETDIRECTION() {
        return fromoffsetdirection;
    }

    /**
     * Sets the value of the fromoffsetdirection property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setFROMOFFSETDIRECTION(UCODEID_Type value) {
        this.fromoffsetdirection = value;
    }

    /**
     * Gets the value of the toreferenceid property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public LINEARREFERENCEID_Type getTOREFERENCEID() {
        return toreferenceid;
    }

    /**
     * Sets the value of the toreferenceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARREFERENCEID_Type }
     *     
     */
    public void setTOREFERENCEID(LINEARREFERENCEID_Type value) {
        this.toreferenceid = value;
    }

    /**
     * Gets the value of the tooffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTOOFFSET() {
        return tooffset;
    }

    /**
     * Sets the value of the tooffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTOOFFSET(QUANTITY value) {
        this.tooffset = value;
    }

    /**
     * Gets the value of the tooffsetdirection property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getTOOFFSETDIRECTION() {
        return tooffsetdirection;
    }

    /**
     * Sets the value of the tooffsetdirection property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setTOOFFSETDIRECTION(UCODEID_Type value) {
        this.tooffsetdirection = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
